@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,8 +24,9 @@
 #include "kdesvn_part.h"
 
 // #include <kprinter.h>
-#include <qpainter.h>
-#include <qcursor.h>
+#include <QPainter>
+#include <QCursor>
+#include <QTimer>
 
 #include <kglobal.h>
 #include <klocale.h>
@@ -113,6 +114,7 @@ kdesvn::kdesvn()
             // tell the KParts::MainWindow that this is indeed the main widget
             setCentralWidget(m_part->widget());
             connect(this,SIGNAL(sigSavestate()),m_part->widget(),SLOT(slotSavestate()));
+            connect(m_part->widget(),SIGNAL(sigExtraStatusMessage(const QString&)),this,SLOT(slotExtraStatus(const QString&)));
 
             KAction*tmpAction;
             tmpAction = actionCollection()->addAction("subversion_create_repo",
@@ -155,8 +157,6 @@ kdesvn::kdesvn()
             tmpAction->setText(i18n("Show database content"));
             tmpAction->setToolTip(i18n("Show the content of logcache database"));
 
-            /* enable tooltips in statusbar for menu */
-// KDE4 port - pv             actionCollection()->setHighlightingEnabled(true);
             connectActionCollection(actionCollection());
 
             setHelpMenuEnabled(false);
@@ -193,13 +193,6 @@ void kdesvn::connectActionCollection( KActionCollection *coll )
 #endif
 }
 
-#if 0
-void kdesvn::actionHovered(QAction*action)
-{
-    if (action) changeStatusbar(action->statusTip());
-}
-#endif
-
 kdesvn::~kdesvn()
 {
 }
@@ -211,6 +204,7 @@ void kdesvn::loadRescent(const KUrl& url)
 
 void kdesvn::load(const KUrl& url,bool addRescent)
 {
+    QTimer::singleShot(100,this,SLOT(slotResetExtraStatus()));
     if (m_part) {
         bool ret = m_part->openUrl(url);
         KRecentFilesAction*rac = 0;
@@ -296,6 +290,8 @@ void kdesvn::fileClose()
         close();
     } else {
         enableClose(false);
+        QTimer::singleShot(100,this,SLOT(slotResetExtraStatus()));
+        enableClose(false);
     }
 }
 
@@ -343,15 +339,12 @@ void kdesvn::fileOpen()
 
 void kdesvn::changeStatusbar(const QString& text)
 {
-    // display the text on the statusbar
-//     statusBar()->message(text);
     statusBar()->showMessage(text);
 }
 
 void kdesvn::resetStatusBar()
 {
-//     statusBar()->message(i18n("Ready"));
-    statusBar()->showMessage(i18n("Ready"));
+    statusBar()->showMessage(i18n("Ready"),4000);
 }
 
 // kde4 port - pv
@@ -398,17 +391,8 @@ void kdesvn::slotUrlOpened(bool how)
  */
 void kdesvn::optionsConfigureToolbars()
 {
-// #if defined(KDE_MAKE_VERSION)
-// # if KDE_VERSION >= KDE_MAKE_VERSION(3,1,0)
-//     saveMainWindowSettings(KGlobal::config(), autoSaveGroup());
     KConfigGroup cg(KGlobal::config(), autoSaveGroup());
     saveMainWindowSettings(cg);
-// # else
-//     saveMainWindowSettings(KGlobal::config() );
-// # endif
-// #else
-//     saveMainWindowSettings(KGlobal::config() );
-// #endif
 
     // use the standard toolbar editor
     KEditToolBar dlg(factory());
@@ -481,4 +465,20 @@ void kdesvn::slotLoadLast(bool how)
     cs.sync();
 }
 
+void kdesvn::slotResetExtraStatus()
+{
+    if (statusBar()->hasItem(1)) {
+        statusBar()->removeItem(1);
+    }
+}
+
+void kdesvn::slotExtraStatus(const QString&what)
+{
+    if (!statusBar()->hasItem(1)) {
+        statusBar()->insertItem(what,1);
+    } else {
+        statusBar()->changeItem(what,1);
+    }
+}
+
 #include "kdesvn.moc"
