@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,25 +19,23 @@
  ***************************************************************************/
 
 
-#ifndef _KDESVNVIEW_H_
-#define _KDESVNVIEW_H_
+#ifndef KDESVNVIEW_H
+#define KDESVNVIEW_H
 
-#include "src/svnqt/repositorylistener.hpp"
+#include "src/svnqt/repositorylistener.h"
 #include <qwidget.h>
 #include <kparts/part.h>
 
 class QPainter;
-class KURL;
-class kdesvnfilelist;
+class KUrl;
 class KdeSvnDirList;
 class QVBoxLayout;
-class QHBoxLayout;
-class QGridLayout;
 class QSpacerItem;
 class QSplitter;
 class KActionCollection;
 class KTextBrowser;
-class KProgress;
+class QProgressBar;
+class MainTreeWidget;
 
 
 /**
@@ -56,7 +54,7 @@ public:
     /**
      * Default constructor
      */
-    kdesvnView(KActionCollection*,QWidget *parent,const char*name=0,bool full=false);
+    kdesvnView(KActionCollection*,QWidget *parent,bool full=false);
 
     /**
      * Destructor
@@ -66,28 +64,33 @@ public:
     /**
      * Random 'get' function
      */
-    QString currentURL();
+    QString currentUrl();
 
     /**
      * Random 'set' function accessed by DCOP
      */
-    virtual bool openURL(QString url);
+    virtual bool openUrl(QString url);
 
     /**
      * Random 'set' function
      */
-    virtual bool openURL(const KURL& url);
+    virtual bool openUrl(const KUrl& url);
 
     /* repositorylistener methods */
     virtual void sendWarning(const QString&);
     virtual void sendError(const QString&);
     virtual bool isCanceld();
+    virtual void stopCacheThreads();
 
-signals:
+Q_SIGNALS:
     /**
      * Use this signal to change the content of the statusbar
      */
     void signalChangeStatusbar(const QString&);
+    /**
+     * Extra messages for a temporary status bar
+     */
+    void sigExtraStatusMessage(const QString&);
 
     /**
      * Use this signal to change the content of the caption
@@ -95,7 +98,7 @@ signals:
     void signalChangeCaption(const QString&);
 
     void sigShowPopup(const QString&,QWidget**);
-    void sigSwitchUrl(const KURL&);
+    void sigSwitchUrl(const KUrl&);
     void setWindowCaption(const QString&);
     void sigUrlChanged(const QString&);
     void sigMakeBaseDirs();
@@ -104,7 +107,7 @@ signals:
     void tickProgress();
     void waitShow(bool);
 
-public slots:
+public Q_SLOTS:
     virtual void closeMe();
     virtual void slotDispPopup(const QString&,QWidget**);
     virtual void refreshCurrentTree();
@@ -116,23 +119,26 @@ public slots:
 
     /* repositorylistener methods */
     virtual void setCanceled(bool);
-    virtual void fillCacheStatus(Q_LONG,Q_LONG);
+    virtual void fillCacheStatus(qlonglong,qlonglong);
 
-protected slots:
+    virtual void slotSavestate();
+
+protected Q_SLOTS:
     virtual void slotOnURL(const QString& url);
     virtual void slotSetTitle(const QString& title);
     virtual void slotAppendLog(const QString& text);
     virtual void slotUrlChanged(const QString&);
 
 protected:
-    kdesvnfilelist*m_flist;
+    //kdesvnfilelist*m_flist;
+    MainTreeWidget*m_TreeWidget;
     KActionCollection*m_Collection;
 
     QSplitter *m_Splitter,*m_infoSplitter;
-    QString m_currentURL;
+    QString m_currentUrl;
     KTextBrowser*m_LogWindow;
     QVBoxLayout*m_topLayout;
-    KProgress*m_CacheProgressBar;
+    QProgressBar*m_CacheProgressBar;
 
 protected:
     virtual void setupActions();
