@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,6 +21,7 @@
 
 #include "cmdexecsettings_impl.h"
 
+#include <kdeversion.h>
 #include <klocale.h>
 #include <knuminput.h>
 #include <qcheckbox.h>
@@ -30,7 +31,11 @@ CmdExecSettings_impl::CmdExecSettings_impl(QWidget* parent)
 : QWidget(parent)
 {
     setupUi(this);
-    kcfg_cmdline_log_minline->setSpecialValueText(i18n("No minimum"));
+#if KDE_IS_VERSION(4, 2, 80)
+    kcfg_cmdline_log_minline->setSuffix(ki18np(" line", " lines"));
+#else
+    kcfg_cmdline_log_minline->setSuffix(i18n(" lines"));
+#endif
     kcfg_cmdline_log_minline->setEnabled(kcfg_cmdline_show_logwindow->isChecked());
     kcfg_kio_standard_logmsg->setEnabled(kcfg_kio_use_standard_logmsg->isChecked());
     kcfg_no_konqueror_toplevelmenu->setDisabled(kcfg_no_konqueror_contextmenu->isChecked());
