@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Rajko Albrecht                                  *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,27 +21,28 @@
 #include "src/settings/kdesvnsettings.h"
 #include "svnfrontend/svnactions.h"
 #include "svnfrontend/dummydisplay.h"
-#include "svnqt/targets.hpp"
-#include "svnqt/url.hpp"
-#include "svnqt/dirent.hpp"
-#include "helpers/sub2qt.h"
-#include "helpers/ktranslateurl.h"
-#include "svnfrontend/fronthelpers/rangeinput_impl.h"
-#include "svnfrontend/copymoveview_impl.h"
+#include "src/svnqt/targets.h"
+#include "src/svnqt/url.h"
+#include "src/svnqt/dirent.h"
+#include "src/helpers/sub2qt.h"
+#include "src/helpers/ktranslateurl.h"
+#include "src/helpers/sshagent.h"
+#include "src/svnfrontend/fronthelpers/rangeinput_impl.h"
+#include "src/svnfrontend/copymoveview_impl.h"
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
-#include <kdialogbase.h>
+// #include <kdialogbase.h>
+#include <KDialog>
+#include <KVBox>
 #include <ktextbrowser.h>
 
 #include <qfile.h>
-#include <qtextstream.h>
-#include <qvaluelist.h>
-#include <qvbox.h>
+#include <QTextStream>
 
 class pCPart
 {
@@ -55,13 +56,13 @@ public:
     bool rev_set;
     bool outfile_set;
     bool single_revision;
+    bool force;
     int log_limit;
     SvnActions*m_SvnWrapper;
     KCmdLineArgs *args;
     svn::Revision start,end;
 
     // for output
-    QFile toStdout,toStderr;
     QString outfile;
     QTextStream Stdout,Stderr;
     DummyDisplay * disp;
@@ -70,17 +71,13 @@ public:
 };
 
 pCPart::pCPart()
-    :cmd(""),url(),ask_revision(false),rev_set(false),outfile_set(false),single_revision(false),log_limit(0)
+    :cmd(""),url(),ask_revision(false),rev_set(false),outfile_set(false),single_revision(false),log_limit(0),Stdout(stdout),Stderr(stderr)
 {
     m_SvnWrapper = 0;
     start = svn::Revision::UNDEFINED;
     end = svn::Revision::UNDEFINED;
-    toStdout.open(IO_WriteOnly, stdout);
-    toStderr.open(IO_WriteOnly, stderr);
-    Stdout.setDevice(&toStdout);
-    Stderr.setDevice(&toStderr);
     disp = new DummyDisplay();
-    m_SvnWrapper = new SvnActions(disp);
+    m_SvnWrapper = new SvnActions(disp,0,true);
 }
 
 pCPart::~pCPart()
@@ -89,11 +86,13 @@ pCPart::~pCPart()
     delete disp;
 }
 
-CommandExec::CommandExec(QObject*parent, const char *name,KCmdLineArgs *args)
-    : QObject(parent,name)
+CommandExec::CommandExec(QObject*parent)
+    : QObject(parent)
 {
     m_pCPart = new pCPart;
-    m_pCPart->args = args;
+    m_pCPart->args = 0;
+    SshAgent ag;
+    ag.querySshAgent();
 
     connect(m_pCPart->m_SvnWrapper,SIGNAL(clientException(const QString&)),this,SLOT(clientException(const QString&)));
     connect(m_pCPart->m_SvnWrapper,SIGNAL(sendNotify(const QString&)),this,SLOT(slotNotifyMessage(const QString&)));
@@ -106,8 +105,9 @@ CommandExec::~CommandExec()
     delete m_pCPart;
 }
 
-int CommandExec::exec()
+int CommandExec::exec(KCmdLineArgs*args)
 {
+    m_pCPart->args=args;
     if (!m_pCPart->args) {
         return -1;
     }
@@ -117,10 +117,12 @@ int CommandExec::exec()
     bool dont_check_second = false;
     bool dont_check_all = false;
     bool path_only = false;
+    bool no_revision = false;
+    bool check_force=false;
 
     if (m_pCPart->args->count()>=2) {
         m_pCPart->cmd=m_pCPart->args->arg(1);
-        m_pCPart->cmd=m_pCPart->cmd.lower();
+        m_pCPart->cmd=m_pCPart->cmd.toLower();
     }
     QString slotCmd;
     if (!QString::compare(m_pCPart->cmd,"log")) {
@@ -193,11 +195,19 @@ int CommandExec::exec()
         slotCmd=SLOT(slotCmd_switch());
     } else if (!QString::compare(m_pCPart->cmd,"tree")) {
         slotCmd=SLOT(slotCmd_tree());
+    } else if (!QString::compare(m_pCPart->cmd,"lock")) {
+        slotCmd=SLOT(slotCmd_lock());
+        no_revision = true;
+        check_force=true;
+    } else if (!QString::compare(m_pCPart->cmd,"unlock")) {
+        slotCmd=SLOT(slotCmd_unlock());
+        no_revision=true;
+        check_force=true;
     }
 
-    bool found = connect(this,SIGNAL(executeMe()),this,slotCmd.ascii());
+    bool found = connect(this,SIGNAL(executeMe()),this,slotCmd.toAscii());
     if (!found) {
-        slotCmd=i18n("Command \"%1\" not implemented or known").arg(m_pCPart->cmd);
+        slotCmd=i18n("Command \"%1\" not implemented or known",m_pCPart->cmd);
         KMessageBox::sorry(0,slotCmd,i18n("SVN Error"));
         return -1;
     }
@@ -205,11 +215,11 @@ int CommandExec::exec()
     QString tmp,query,proto,v;
     QMap<QString,QString> q;
 
-    KURL tmpurl;
+    KUrl tmpurl;
     QString mainProto;
     QString _baseurl;
     for (int j = 2; j<m_pCPart->args->count();++j) {
-        tmpurl = helpers::KTranslateUrl::translateSystemUrl(m_pCPart->args->url(j));
+        tmpurl = helpers::KTranslateUrl::translateSystemUrl(m_pCPart->args->url(j).prettyUrl());
         query = tmpurl.query();
         q = m_pCPart->args->url(j).queryItems();
         if (q.find("rev")!=q.end()) {
@@ -218,7 +228,11 @@ int CommandExec::exec()
             v = "";
         }
         tmpurl.setProtocol(svn::Url::transformProtokoll(tmpurl.protocol()));
-        kdDebug()<<"Urlpath: " << tmpurl.path()<<endl;
+        if (tmpurl.protocol().indexOf("ssh")!=-1) {
+            SshAgent ag;
+            // this class itself checks if done before
+            ag.addSshIdentities();
+        }
         m_pCPart->extraRevisions[j-2]=svn::Revision::HEAD;
 
         if (tmpurl.isLocalFile() && (j==2 || !dont_check_second) && !dont_check_all) {
@@ -242,39 +256,44 @@ int CommandExec::exec()
                 tmp = tmpurl.path();
             }
         }
-        QStringList l = QStringList::split('?',tmp);
+        QStringList l = tmp.split('?',QString::SkipEmptyParts);
         if (l.count()>0) {
             tmp=l[0];
         }
-        while (tmp.endsWith("/")) {
+        while (tmp.endsWith('/')) {
             tmp.truncate(tmp.length()-1);
         }
         m_pCPart->url.append(tmp);
-        kdDebug()<<"Resulting url: "<<tmp<<endl;
         if ( (j>2 && dont_check_second) || dont_check_all) {
             continue;
         }
-        svn::Revision re,ra;
-        m_pCPart->m_SvnWrapper->svnclient()->url2Revision(v,re,ra);
-
-        if (re != svn::Revision::UNDEFINED) {
-            kdDebug()<<"Revision " << re << " gefunden. " << endl;
+        svn::Revision re = v;
+        if (re) {
             m_pCPart->extraRevisions[j-2]=re;
         }
-        kdDebug()<<"Uri zum testen: " << tmpurl<<endl;
     }
     if (m_pCPart->url.count()==0) {
         m_pCPart->url.append(".");
     }
 
-    if (m_pCPart->args->isSet("R")) {
-        m_pCPart->ask_revision = true;
-        if (!askRevision()) {
-            return 0;
+    if (!no_revision)
+    {
+        if (m_pCPart->args->isSet("R"))
+        {
+            m_pCPart->ask_revision = true;
+            if (!askRevision())
+            {
+                return 0;
+            }
+        }
+        else if (m_pCPart->args->isSet("r"))
+        {
+            scanRevision();
         }
-    } else if (m_pCPart->args->isSet("r")){
-        scanRevision();
     }
+
+    m_pCPart->force=check_force && m_pCPart->args->isSet("f");
+
     if (m_pCPart->args->isSet("o")) {
         m_pCPart->outfile_set=true;
         m_pCPart->outfile = m_pCPart->args->getOption("o");
@@ -290,19 +309,15 @@ int CommandExec::exec()
     emit executeMe();
     if (Kdesvnsettings::self()->cmdline_show_logwindow() &&
         m_lastMessagesLines >= Kdesvnsettings::self()->cmdline_log_minline()) {
-        KDialogBase dlg (
-            KApplication::activeModalWidget(),
-            "execution_log",
-            true,
-            i18n("Execution log"),
-            KDialogBase::Ok);
-
-        QWidget* Dialog1Layout = dlg.makeVBoxMainWidget();
+        KDialog dlg(KApplication::activeModalWidget());
+        KVBox *Dialog1Layout = new KVBox(&dlg);
+        dlg.setMainWidget(Dialog1Layout);
         KTextBrowser*ptr = new KTextBrowser(Dialog1Layout);
         ptr->setText(m_lastMessages);
-        dlg.resize(dlg.configDialogSize(*(Kdesvnsettings::self()->config()),"kdesvn_cmd_log"));
+        KConfigGroup _k(Kdesvnsettings::self()->config(),"kdesvn_cmd_log");
+        dlg.restoreDialogSize(_k);
         dlg.exec();
-        dlg.saveDialogSize(*(Kdesvnsettings::self()->config()),"kdesvn_cmd_log",false);
+        dlg.saveDialogSize(_k);
     }
     return 0;
 }
@@ -319,11 +334,9 @@ void CommandExec::clientException(const QString&what)
 }
 
 
-/*!
-    \fn CommandExec::slotCmdLog
- */
 void CommandExec::slotCmd_log()
 {
+    int limit = m_pCPart->log_limit;
     if (m_pCPart->end == svn::Revision::UNDEFINED) {
         m_pCPart->end = svn::Revision::HEAD;
     }
@@ -331,12 +344,15 @@ void CommandExec::slotCmd_log()
         m_pCPart->start = 1;
     }
     bool list = Kdesvnsettings::self()->log_always_list_changed_files();
-    m_pCPart->m_SvnWrapper->makeLog(m_pCPart->start,m_pCPart->end,m_pCPart->url[0],list,m_pCPart->log_limit);
+    if (m_pCPart->extraRevisions[0]==svn::Revision::WORKING) {
+        m_pCPart->extraRevisions[0]=svn::Revision::UNDEFINED;
+    }
+    m_pCPart->m_SvnWrapper->makeLog(m_pCPart->start,m_pCPart->end,m_pCPart->extraRevisions[0],m_pCPart->url[0],
+            Kdesvnsettings::log_follows_nodes(),
+            list,
+            limit);
 }
 
-/*!
-    \fn CommandExec::slotCmdLog
- */
 void CommandExec::slotCmd_tree()
 {
     if (m_pCPart->end == svn::Revision::UNDEFINED) {
@@ -370,10 +386,10 @@ void CommandExec::slotCmd_exportto()
 
 void CommandExec::slotCmd_blame()
 {
-    if (m_pCPart->end == svn::Revision::UNDEFINED) {
+    if (!m_pCPart->end) {
         m_pCPart->end = svn::Revision::HEAD;
     }
-    if (m_pCPart->start == svn::Revision::UNDEFINED) {
+    if (!m_pCPart->start) {
         m_pCPart->start = 1;
     }
     m_pCPart->m_SvnWrapper->makeBlame(m_pCPart->start,m_pCPart->end,m_pCPart->url[0]);
@@ -386,9 +402,7 @@ void CommandExec::slotCmd_cat()
         m_pCPart->start=m_pCPart->extraRevisions[0];
     } else {
         m_pCPart->end = svn::Revision::HEAD;
-        kdDebug()<<"Setting head standard for cat"<<endl;
     }
-    kdDebug()<<"Rev set "<<m_pCPart->rev_set<<endl;
     m_pCPart->m_SvnWrapper->slotMakeCat(
         (m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),m_pCPart->url[0],m_pCPart->url[0]
         ,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),0);
@@ -401,13 +415,11 @@ void CommandExec::slotCmd_get()
         m_pCPart->start=m_pCPart->extraRevisions[0];
     } else {
         m_pCPart->end = svn::Revision::HEAD;
-        kdDebug()<<"Setting head standard for get";
     }
     if (!m_pCPart->outfile_set || m_pCPart->outfile.isEmpty()) {
         clientException(i18n("\"GET\" requires output file!"));
         return;
     }
-    kdDebug()<<"write to "<<m_pCPart->outfile<<endl;
     m_pCPart->m_SvnWrapper->makeGet((m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),m_pCPart->url[0], m_pCPart->outfile,
         (m_pCPart->rev_set?m_pCPart->start:m_pCPart->end));
 }
@@ -415,18 +427,17 @@ void CommandExec::slotCmd_get()
 void CommandExec::slotCmd_update()
 {
     m_pCPart->m_SvnWrapper->makeUpdate(m_pCPart->url,
-        (m_pCPart->rev_set?m_pCPart->start:svn::Revision::HEAD),true);
+        (m_pCPart->rev_set?m_pCPart->start:svn::Revision::HEAD),svn::DepthUnknown);
 }
 
 void CommandExec::slotCmd_diff()
 {
     if (m_pCPart->url.count()==1) {
         if (!m_pCPart->rev_set && !svn::Url::isValid(m_pCPart->url[0])) {
-            kdDebug()<<"Local diff" << endl;
-            m_pCPart->start = svn::Revision::UNDEFINED;
-            m_pCPart->end = svn::Revision::UNDEFINED;
+            m_pCPart->start = svn::Revision::BASE;
+            m_pCPart->end = svn::Revision::WORKING;
         }
-        m_pCPart->m_SvnWrapper->makeDiff(m_pCPart->url[0],m_pCPart->start,m_pCPart->end);
+        m_pCPart->m_SvnWrapper->makeDiff(m_pCPart->url[0],m_pCPart->start,m_pCPart->url[0],m_pCPart->end);
     } else {
         svn::Revision r1 = svn::Revision::HEAD;
         svn::Revision r2 = svn::Revision::HEAD;
@@ -455,8 +466,8 @@ void CommandExec::slotCmd_info()
 
 void CommandExec::slotCmd_commit()
 {
-    QValueList<svn::Path> targets;
-    for (unsigned j=0; j<m_pCPart->url.count();++j) {
+    QStringList targets;
+    for (long j=0; j<m_pCPart->url.count();++j) {
         targets.push_back(svn::Path(m_pCPart->url[j]));
     }
     m_pCPart->m_SvnWrapper->makeCommit(svn::Targets(targets));
@@ -465,15 +476,21 @@ void CommandExec::slotCmd_commit()
 void CommandExec::slotCmd_list()
 {
     svn::DirEntries res;
-    if (!m_pCPart->m_SvnWrapper->makeList(m_pCPart->url[0],res,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end),false)) {
+    svn::Revision rev = m_pCPart->end;
+    if (m_pCPart->rev_set){
+        rev = m_pCPart->start;
+    } else if (m_pCPart->extraRevisions[0]) {
+        rev = m_pCPart->extraRevisions[0];
+    }
+    if (!m_pCPart->m_SvnWrapper->makeList(m_pCPart->url[0],res,rev,svn::DepthInfinity)) {
         return;
     }
-    for (unsigned int i = 0; i < res.count();++i) {
-        QString d = helpers::sub2qt::apr_time2qt(res[i].time()).toString(QString("yy-MM-dd hh:mm::ss"));
+    for (long i = 0; i < res.count();++i) {
+        QString d = svn::DateTime(res[i]->time()).toString(QString("yyyy-MM-dd hh:mm::ss"));
         m_pCPart->Stdout
-            << (res[i].kind()==svn_node_dir?"D":"F")<<" "
+            << (res[i]->kind()==svn_node_dir?"D":"F")<<" "
             << d << " "
-            << res[i].name()<<endl;
+            << res[i]->name()<<endl;
     }
 }
 
@@ -495,7 +512,6 @@ void CommandExec::slotCmd_copy()
         m_pCPart->start=m_pCPart->extraRevisions[0];
     } else {
         m_pCPart->end = svn::Revision::HEAD;
-        kdDebug()<<"Setting head standard for copy"<<endl;
     }
     m_pCPart->m_SvnWrapper->makeCopy(m_pCPart->url[0],target,(m_pCPart->rev_set?m_pCPart->start:m_pCPart->end));
 }
@@ -524,12 +540,12 @@ void CommandExec::slotCmd_delete()
 
 void CommandExec::slotCmd_add()
 {
-    m_pCPart->m_SvnWrapper->addItems(m_pCPart->url,true);
+    m_pCPart->m_SvnWrapper->addItems(m_pCPart->url,svn::DepthInfinity);
 }
 
 void CommandExec::slotCmd_revert()
 {
-    m_pCPart->m_SvnWrapper->slotRevertItems(m_pCPart->url);
+    m_pCPart->m_SvnWrapper->slotRevertItems(m_pCPart->url,false);
 }
 
 void CommandExec::slotCmd_addnew()
@@ -542,13 +558,15 @@ void CommandExec::slotCmd_addnew()
  */
 bool CommandExec::scanRevision()
 {
-    /// @todo scan for date-ranges, too.
     QString revstring = m_pCPart->args->getOption("r");
-    QStringList revl = QStringList::split(":",revstring);
+    QStringList revl = revstring.split(':',QString::SkipEmptyParts);
     if (revl.count()==0) {
         return false;
     }
-    m_pCPart->m_SvnWrapper->svnclient()->url2Revision(revstring,m_pCPart->start,m_pCPart->end);
+    m_pCPart->start = revl[0];
+    if (revl.count()>1) {
+        m_pCPart->end = revl[1];
+    }
     m_pCPart->rev_set=true;
     return true;
 }
@@ -566,13 +584,11 @@ void CommandExec::slotNotifyMessage(const QString&msg)
 bool CommandExec::askRevision()
 {
     QString _head = m_pCPart->cmd+" - Revision";
-    KDialogBase dlg(
-        0,
-        "Revisiondlg",
-        true,
-        _head,
-        KDialogBase::Ok|KDialogBase::Cancel);
-    QWidget* Dialog1Layout = dlg.makeVBoxMainWidget();
+    KDialog dlg(0);
+    dlg.setButtons(KDialog::Ok | KDialog::Cancel);
+    KVBox *Dialog1Layout = new KVBox(&dlg);
+    dlg.setMainWidget(Dialog1Layout);
+
     Rangeinput_impl*rdlg;
     rdlg = new Rangeinput_impl(Dialog1Layout);
     dlg.resize( QSize(120,60).expandedTo(dlg.minimumSizeHint()));
@@ -606,4 +622,16 @@ void CommandExec::slotCmd_switch()
     m_pCPart->m_SvnWrapper->makeSwitch(m_pCPart->url[0],base);
 }
 
+void CommandExec::slotCmd_lock()
+{
+//     m_pCPart->m_SvnWrapper->makeLock(m_pCPart->url[0],"",m_pCPart->force);
+    m_pCPart->m_SvnWrapper->makeLock(m_pCPart->url,"",m_pCPart->force);
+}
+
+void CommandExec::slotCmd_unlock()
+{
+//     m_pCPart->m_SvnWrapper->makeUnlock(m_pCPart->url[0],m_pCPart->force);
+    m_pCPart->m_SvnWrapper->makeUnlock(m_pCPart->url,m_pCPart->force);
+}
+
 #include "commandexec.moc"
