@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2006-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,8 +22,8 @@
 
 #include "ui_createrepo_dlg.h"
 
-#include "src/svnqt/svnqttypes.hpp"
-#include "src/svnqt/shared_pointer.hpp"
+#include "src/svnqt/svnqttypes.h"
+#include "src/svnqt/shared_pointer.h"
 
 class CreateRepoData;
 
