@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,9 +22,9 @@
 
 #include "ui_svnlogdlg.h"
 #include "simple_logcb.h"
-#include "src/svnqt/log_entry.hpp"
-#include "src/svnqt/client.hpp"
-#include "src/svnqt/shared_pointer.hpp"
+#include "src/svnqt/log_entry.h"
+#include "src/svnqt/client.h"
+#include "src/svnqt/shared_pointer.h"
 
 #include <qsize.h>
 #include <QKeyEvent>
