@@ -1,36 +1,54 @@
-#include "ReposLog.hpp"
+/***************************************************************************
+ *   Copyright (C) 2005-2009 by Rajko Albrecht  ral@alwins-world.de        *
+ *   http://kdesvn.alwins-world.de/                                        *
+ *                                                                         *
+ * This program is free software; you can redistribute it and/or           *
+ * modify it under the terms of the GNU Lesser General Public              *
+ * License as published by the Free Software Foundation; either            *
+ * version 2.1 of the License, or (at your option) any later version.      *
+ *                                                                         *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ * Lesser General Public License for more details.                         *
+ *                                                                         *
+ * You should have received a copy of the GNU Lesser General Public        *
+ * License along with this program (in the file LGPL.txt); if not,         *
+ * write to the Free Software Foundation, Inc., 51 Franklin St,            *
+ * Fifth Floor, Boston, MA  02110-1301  USA                                *
+ *                                                                         *
+ * This software consists of voluntary contributions made by many          *
+ * individuals.  For exact contribution history, see the revision          *
+ * history and logs, available at http://kdesvn.alwins-world.de.           *
+ ***************************************************************************/
+#include "ReposLog.h"
 
-#include "LogCache.hpp"
-#include "svnqt/info_entry.hpp"
-#include "svnqt/svnqttypes.hpp"
-#include "svnqt/client.hpp"
-#include "svnqt/context_listener.hpp"
-#include "svnqt/cache/DatabaseException.hpp"
+#include "LogCache.h"
+#include "svnqt/info_entry.h"
+#include "svnqt/svnqttypes.h"
+#include "svnqt/client.h"
+#include "svnqt/context_listener.h"
+#include "svnqt/cache/DatabaseException.h"
+#include "svnqt/client_parameter.h"
 
 #include <qsqldatabase.h>
 
-#if QT_VERSION < 0x040000
-#else
 #include <QSqlError>
 #include <QSqlQuery>
 #include <QVariant>
+#include <QFileInfo>
+#include <QBuffer>
 #define Q_LLONG qlonglong
-#endif
 
 /*!
     \fn svn::cache::ReposLog::ReposLog(svn::Client*aClient,const QString&)
  */
 svn::cache::ReposLog::ReposLog(svn::Client*aClient,const QString&aRepository)
     :m_Client(),
-#if QT_VERSION < 0x040000
-              m_Database(0),
-#else
               m_Database(),
-#endif
               m_ReposRoot(aRepository),m_latestHead(svn::Revision::UNDEFINED)
 {
     m_Client=aClient;
-    ContextP ctx = m_Client->getContext();
     if (!aRepository.isEmpty()) {
         m_Database = LogCache::self()->reposDb(aRepository);
     }
@@ -45,27 +63,19 @@ svn::Revision svn::cache::ReposLog::latestHeadRev()
     if (!m_Client||m_ReposRoot.isEmpty()) {
         return svn::Revision::UNDEFINED;
     }
-#if QT_VERSION < 0x040000
-    if (!m_Database) {
-#else
     if (!m_Database.isValid()) {
-#endif
         m_Database = LogCache::self()->reposDb(m_ReposRoot);
-#if QT_VERSION < 0x040000
-        if (!m_Database) {
-#else
         if (!m_Database.isValid()) {
-#endif
             return svn::Revision::UNDEFINED;
         }
     }
     /// no catch - exception has go trough...
-    qDebug("Getting headrev");
+    //qDebug("Getting headrev");
     svn::InfoEntries e = m_Client->info(m_ReposRoot,svn::DepthEmpty,svn::Revision::HEAD,svn::Revision::HEAD);
     if (e.count()<1||e[0].reposRoot().isEmpty()) {
         return svn::Revision::UNDEFINED;
     }
-    qDebug("Getting headrev done");
+    //qDebug("Getting headrev done");
     return e[0].revision();
 }
 
@@ -78,24 +88,16 @@ svn::Revision svn::cache::ReposLog::latestCachedRev()
     if (m_ReposRoot.isEmpty()) {
         return svn::Revision::UNDEFINED;
     }
-#if QT_VERSION < 0x040000
-    if (!m_Database) {
-#else
     if (!m_Database.isValid()) {
-#endif
         m_Database = LogCache::self()->reposDb(m_ReposRoot);
-#if QT_VERSION < 0x040000
-        if (!m_Database) {
-#else
         if (!m_Database.isValid()) {
-#endif
             return svn::Revision::UNDEFINED;
         }
     }
     QString q("select revision from 'logentries' order by revision DESC limit 1");
-    QSqlQuery _q(QString::null, m_Database);
+    QSqlQuery _q(QString(), m_Database);
     if (!_q.exec(q)) {
-        qDebug(_q.lastError().text().TOUTF8().data());
+        //qDebug() << _q.lastError().text();
         return svn::Revision::UNDEFINED;
     }
     int _r;
@@ -103,34 +105,101 @@ svn::Revision svn::cache::ReposLog::latestCachedRev()
         //qDebug("Sel result: %s",_q.value(0).toString().TOUTF8().data());
         _r = _q.value(0).toInt();
     } else {
-        qDebug(_q.lastError().text().TOUTF8().data());
+        //qDebug() << _q.lastError().text();
         return svn::Revision::UNDEFINED;
     }
     return _r;
 }
 
+qlonglong svn::cache::ReposLog::count()const
+{
+    if (!m_Database.isValid()) {
+        m_Database = LogCache::self()->reposDb(m_ReposRoot);
+        if (!m_Database.isValid()) {
+            return svn::Revision::UNDEFINED;
+        }
+    }
+    QString q("select count(*) from 'logentries'");
+    QSqlQuery _q(QString(), m_Database);
+    if (!_q.exec(q)) {
+        //qDebug() << _q.lastError().text();
+        return -1;
+    }
+    qlonglong _r;
+    QVariant v;
+    if (_q.isActive() && _q.next()) {
+        //qDebug("Sel result: %s",_q.value(0).toString().TOUTF8().data());
+        v=_q.value(0);
+        if (v.canConvert(QVariant::LongLong)) {
+            bool ok = false;
+            _r = v.toLongLong(&ok);
+            if (ok) {
+                return _r;
+            }
+        }
+    }
+    return -1;
+}
+
+qlonglong svn::cache::ReposLog::fileSize()const
+{
+    if (!m_Database.isValid()) {
+        m_Database = LogCache::self()->reposDb(m_ReposRoot);
+        if (!m_Database.isValid()) {
+            return -1;
+        }
+    }
+    QFileInfo fi(m_Database.databaseName());
+    if (fi.exists()) {
+        return fi.size();
+    }
+    return -1;
+}
+
+qlonglong svn::cache::ReposLog::itemCount()const
+{
+    if (!m_Database.isValid()) {
+        m_Database = LogCache::self()->reposDb(m_ReposRoot);
+        if (!m_Database.isValid()) {
+            return -1;
+        }
+    }
+    QString q("select count(*) from 'changeditems'");
+    QSqlQuery _q(QString(), m_Database);
+    if (!_q.exec(q)) {
+        //qDebug() << _q.lastError().text();
+        return -1;
+    }
+    qlonglong _r;
+    QVariant v;
+    if (_q.isActive() && _q.next()) {
+        //qDebug("Sel result: %s",_q.value(0).toString().TOUTF8().data());
+        v=_q.value(0);
+        if (v.canConvert(QVariant::LongLong)) {
+            bool ok = false;
+            _r = v.toLongLong(&ok);
+            if (ok) {
+                return _r;
+            }
+        }
+    }
+    return -1;
+}
+
 bool svn::cache::ReposLog::checkFill(svn::Revision&start,svn::Revision&end,bool checkHead)
 {
-#if QT_VERSION < 0x040000
-    if (!m_Database) {
-#else
     if (!m_Database.isValid()) {
-#endif
         m_Database = LogCache::self()->reposDb(m_ReposRoot);
-#if QT_VERSION < 0x040000
-        if (!m_Database) {
-#else
         if (!m_Database.isValid()) {
-#endif
             return false;
         }
     }
     ContextP cp = m_Client->getContext();
-    long long icount=0;
+//     long long icount=0;
 
     svn::Revision _latest=latestCachedRev();
-//    qDebug("Latest cached rev: %i",_latest.revnum());
-//    qDebug("End revision is: %s",end.toString().TOUTF8().data());
+//    //qDebug("Latest cached rev: %i",_latest.revnum());
+//    //qDebug("End revision is: %s",end.toString().TOUTF8().data());
 
     if (checkHead && _latest.revnum()>=latestHeadRev().revnum()) {
         return true;
@@ -148,22 +217,24 @@ bool svn::cache::ReposLog::checkFill(svn::Revision&start,svn::Revision&end,bool
     svn::Revision _rstart=_latest.revnum()+1;
     svn::Revision _rend = end;
     if (_rend==svn::Revision::UNDEFINED) {
-//        qDebug("Setting end to Head");
+//        //qDebug("Setting end to Head");
         _rend=svn::Revision::HEAD;
     }
     // no catch - exception should go outside.
     if (_rstart==0){
         _rstart = 1;
     }
-//    qDebug("Getting log %s -> %s",_rstart.toString().TOUTF8().data(),_rend.toString().TOUTF8().data());
+//    //qDebug("Getting log %s -> %s",_rstart.toString().TOUTF8().data(),_rend.toString().TOUTF8().data());
     if (_rend==svn::Revision::HEAD) {
         _rend=latestHeadRev();
     }
 
     if (_rend==svn::Revision::HEAD||_rend.revnum()>_latest.revnum()) {
         LogEntriesMap _internal;
-//        qDebug("Retrieving from network.");
-        if (!m_Client->log(m_ReposRoot,_rstart,_rend,_internal,svn::Revision::UNDEFINED,true,false)) {
+//        //qDebug("Retrieving from network.");
+        LogParameter params;
+
+        if (!m_Client->log(params.targets(m_ReposRoot).revisionRange(_rstart,_rend).peg(svn::Revision::UNDEFINED).discoverChangedPathes(true).strictNodeHistory(false),_internal)) {
             return false;
         }
         LogEntriesMap::ConstIterator it=_internal.begin();
@@ -191,7 +262,7 @@ bool svn::cache::ReposLog::fillCache(const svn::Revision&_end)
 /*!
     \fn svn::cache::ReposLog::simpleLog(const svn::Revision&start,const svn::Revision&end,LogEntriesMap&target)
  */
-bool svn::cache::ReposLog::simpleLog(LogEntriesMap&target,const svn::Revision&_start,const svn::Revision&_end,bool noNetwork)
+bool svn::cache::ReposLog::simpleLog(LogEntriesMap&target,const svn::Revision&_start,const svn::Revision&_end,bool noNetwork,const QStringList&exclude)
 {
     if (!m_Client||m_ReposRoot.isEmpty()) {
         return false;
@@ -220,19 +291,21 @@ bool svn::cache::ReposLog::simpleLog(LogEntriesMap&target,const svn::Revision&_s
     static QString sEntry("select revision,author,date,message from logentries where revision<=? and revision>=?");
     static QString sItems("select changeditem,action,copyfrom,copyfromrev from changeditems where revision=?");
 
-    QSqlQuery bcount(QString::null,m_Database);
+    for (int i = 0; i < exclude.size();++i) {
+        sItems+=" and changeditem not like '"+exclude[i]+"%'";
+    }
+
+    QSqlQuery bcount(QString(),m_Database);
     bcount.prepare(sCount);
 
-    QSqlQuery bcur(QString::null,m_Database);
-    bcur.prepare(sEntry);
+    QSqlQuery bcur(QString(),m_Database);
 
-    QSqlQuery cur(QString::null,m_Database);
-    cur.prepare(sItems);
+    QSqlQuery cur(QString(),m_Database);
 
     bcount.bindValue(0,Q_LLONG(end.revnum()));
     bcount.bindValue(1,Q_LLONG(start.revnum()));
     if (!bcount.exec()) {
-        qDebug(bcount.lastError().text().TOUTF8().data());
+        //qDebug() << bcount.lastError().text();
         throw svn::cache::DatabaseException(QString("Could not retrieve count: ")+bcount.lastError().text());
         return false;
     }
@@ -242,21 +315,23 @@ bool svn::cache::ReposLog::simpleLog(LogEntriesMap&target,const svn::Revision&_s
         return false;
     }
 
+    bcur.prepare(sEntry);
     bcur.bindValue(0,Q_LLONG(end.revnum()));
     bcur.bindValue(1,Q_LLONG(start.revnum()));
 
     if (!bcur.exec()) {
-        qDebug(bcur.lastError().text().TOUTF8().data());
         throw svn::cache::DatabaseException(QString("Could not retrieve values: ")+bcur.lastError().text());
         return false;
     }
     Q_LLONG revision;
     while(bcur.next()) {
+        cur.prepare(sItems);
         revision = bcur.value(0).toLongLong();
         cur.bindValue(0,revision);
+
         if (!cur.exec()) {
-            qDebug(cur.lastError().text().TOUTF8().data());
-            throw svn::cache::DatabaseException(QString("Could not retrieve values: ")+cur.lastError().text()
+            //qDebug() << cur.lastError().text();
+            throw svn::cache::DatabaseException(QString("Could not retrieve revision values: ")+cur.lastError().text()
                     ,cur.lastError().number());
             return false;
         }
@@ -267,11 +342,7 @@ bool svn::cache::ReposLog::simpleLog(LogEntriesMap&target,const svn::Revision&_s
         while(cur.next()) {
             LogChangePathEntry lcp;
             QString ac = cur.value(1).toString();
-#if QT_VERSION < 0x040000
-            lcp.action=ac[0].latin1();
-#else
             lcp.action=ac[0].toLatin1();
-#endif
             lcp.copyFromPath=cur.value(2).toString();
             lcp.path= cur.value(0).toString();
             lcp.copyFromRevision=cur.value(3).toLongLong();
@@ -296,22 +367,14 @@ svn::Revision svn::cache::ReposLog::date2numberRev(const svn::Revision&aRev,bool
     if (aRev!=svn::Revision::DATE) {
         return aRev;
     }
-#if QT_VERSION < 0x040000
-    if (!m_Database) {
-#else
     if (!m_Database.isValid()) {
-#endif
         return svn::Revision::UNDEFINED;
     }
     static QString _q("select revision from logentries where date<? order by revision desc");
     QSqlQuery query("select revision,date from logentries order by revision desc limit 1",m_Database);
 
-#if QT_VERSION < 0x040000
-    if (query.lastError().type()!=QSqlError::None) {
-#else
     if (query.lastError().type()!=QSqlError::NoError) {
-#endif
-        qDebug(query.lastError().text().TOUTF8().data());
+        //qDebug() << query.lastError().text();
     }
     bool must_remote=!noNetwork;
     if (query.next()) {
@@ -329,12 +392,8 @@ svn::Revision svn::cache::ReposLog::date2numberRev(const svn::Revision&aRev,bool
     query.prepare(_q);
     query.bindValue(0,Q_LLONG(aRev.date()));
     query.exec();
-#if QT_VERSION < 0x040000
-    if (query.lastError().type()!=QSqlError::None) {
-#else
     if (query.lastError().type()!=QSqlError::NoError) {
-#endif
-        qDebug(query.lastError().text().TOUTF8().data());
+        //qDebug() << query.lastError().text();
     }
     if (query.next()) {
         return query.value(0).toInt();
@@ -356,32 +415,21 @@ svn::Revision svn::cache::ReposLog::date2numberRev(const svn::Revision&aRev,bool
  */
 bool svn::cache::ReposLog::_insertLogEntry(const svn::LogEntry&aEntry)
 {
-    QSqlRecord *buffer;
-
-#if QT_VERSION < 0x040000
-    m_Database->transaction();
-    Q_LLONG j = aEntry.revision;
-#else
     m_Database.transaction();
     qlonglong j = aEntry.revision;
-#endif
     static QString qEntry("insert into logentries (revision,date,author,message) values (?,?,?,?)");
     static QString qPathes("insert into changeditems (revision,changeditem,action,copyfrom,copyfromrev) values (?,?,?,?,?)");
-    QSqlQuery _q(QString::null,m_Database);
+    QSqlQuery _q(QString(),m_Database);
     _q.prepare(qEntry);
     _q.bindValue(0,j);
     _q.bindValue(1,aEntry.date);
     _q.bindValue(2,aEntry.author);
     _q.bindValue(3,aEntry.message);
     if (!_q.exec()) {
-#if QT_VERSION < 0x040000
-        m_Database->rollback();
-#else
         m_Database.rollback();
-#endif
-        qDebug("Could not insert values: %s",_q.lastError().text().TOUTF8().data());
-        qDebug(_q.lastQuery().TOUTF8().data());
-        throw svn::cache::DatabaseException(QString("Could not insert values: ")+_q.lastError().text(),_q.lastError().number());
+        //qDebug("Could not insert values: %s",_q.lastError().text().TOUTF8().data());
+        //qDebug() << _q.lastQuery();
+        throw svn::cache::DatabaseException(QString("_insertLogEntry_0: Could not insert values: ")+_q.lastError().text(),_q.lastError().number());
     }
     _q.prepare(qPathes);
     svn::LogChangePathEntries::ConstIterator cpit = aEntry.changedPaths.begin();
@@ -392,21 +440,31 @@ bool svn::cache::ReposLog::_insertLogEntry(const svn::LogEntry&aEntry)
         _q.bindValue(3,(*cpit).copyFromPath);
         _q.bindValue(4,Q_LLONG((*cpit).copyFromRevision));
         if (!_q.exec()) {
-#if QT_VERSION < 0x040000
-            m_Database->rollback();
-#else
             m_Database.rollback();
-#endif
-            qDebug("Could not insert values: %s",_q.lastError().text().TOUTF8().data());
-            qDebug(_q.lastQuery().TOUTF8().data());
+            //qDebug("Could not insert values: %s",_q.lastError().text().TOUTF8().data());
+            //qDebug() << _q.lastQuery();
             throw svn::cache::DatabaseException(QString("Could not insert values: ")+_q.lastError().text(),_q.lastError().number());
         }
     }
-#if QT_VERSION < 0x040000
-        m_Database->commit();
-#else
-        m_Database.commit();
-#endif
+    if (aEntry.m_MergedInRevisions.size()>0) {
+        static QString qMerges("insert into mergeditems(revision,mergeditems) values(?,?)");
+        _q.prepare(qMerges);
+        QByteArray _merges;
+        QBuffer buffer(&_merges);
+        buffer.open(QIODevice::ReadWrite);
+        QDataStream af(&buffer);
+        af << aEntry.m_MergedInRevisions;
+        buffer.close();
+        _q.bindValue(0,j);
+        _q.bindValue(1,_merges.data());
+        if (!_q.exec()) {
+            m_Database.rollback();
+            //qDebug("Could not insert values: %s",_q.lastError().text().TOUTF8().data());
+            //qDebug() << _q.lastQuery();
+            throw svn::cache::DatabaseException(QString("Could not insert values: ")+_q.lastError().text(),_q.lastError().number());
+        }
+    }
+    m_Database.commit();
     return true;
 }
 
@@ -421,9 +479,11 @@ bool svn::cache::ReposLog::insertLogEntry(const svn::LogEntry&aEntry)
  */
 bool svn::cache::ReposLog::log(const svn::Path&what,const svn::Revision&_start, const svn::Revision&_end,const svn::Revision&_peg,svn::LogEntriesMap&target, bool strictNodeHistory,int limit)
 {
+    Q_UNUSED(strictNodeHistory);
     static QString s_q("select logentries.revision,logentries.author,logentries.date,logentries.message from logentries where logentries.revision in (select changeditems.revision from changeditems where (changeditems.changeditem='%1' or changeditems.changeditem GLOB '%2/*') %3 GROUP BY changeditems.revision) ORDER BY logentries.revision DESC");
 
     static QString s_e("select changeditem,action,copyfrom,copyfromrev from changeditems where changeditems.revision='%1'");
+    static QString s_m("select mergeditems from mergeditems where mergeditems.revision='%1'");
 
     svn::Revision peg = date2numberRev(_peg,true);
     svn::Revision end = date2numberRev(_end,true);
@@ -438,12 +498,12 @@ bool svn::cache::ReposLog::log(const svn::Path&what,const svn::Revision&_start,
     if (limit>0) {
         query_string+=QString(" LIMIT %1").arg(limit);
     }
-    QSqlQuery _q(QString::null,m_Database);
-    QSqlQuery _q2(QString::null,m_Database);
+    QSqlQuery _q(QString(),m_Database);
+    QSqlQuery _q2(QString(),m_Database);
     _q.prepare(query_string);
     if (!_q.exec()) {
-        qDebug("Could not select values: %s",_q.lastError().text().TOUTF8().data());
-        qDebug(_q.lastQuery().TOUTF8().data());
+        //qDebug("Could not select values: %s",_q.lastError().text().TOUTF8().data());
+        //qDebug() << _q.lastQuery();
         throw svn::cache::DatabaseException(QString("Could not select values: ")+_q.lastError().text(),_q.lastError().number());
     }
     while(_q.next()) {
@@ -455,18 +515,9 @@ bool svn::cache::ReposLog::log(const svn::Path&what,const svn::Revision&_start,
         query_string=s_e.arg(revision);
         _q2.prepare(query_string);
         if (!_q2.exec()) {
-            qDebug("Could not select values: %s",_q2.lastError().text().TOUTF8().data());
+            //qDebug("Could not select values: %s",_q2.lastError().text().TOUTF8().data());
         } else {
             while (_q2.next()) {
-#if QT_VERSION < 0x040000
-                target[revision].changedPaths.push_back (
-                        LogChangePathEntry (_q2.value(0).toString(),
-                                            _q2.value(1).toString()[0],
-                                            _q2.value(2).toString(),
-                                            _q2.value(3).toLongLong()
-                                           )
-                                                        );
-#else
                 target[revision].changedPaths.push_back (
                         LogChangePathEntry (_q2.value(0).toString(),
                                             _q2.value(1).toChar().toLatin1(),
@@ -474,10 +525,20 @@ bool svn::cache::ReposLog::log(const svn::Path&what,const svn::Revision&_start,
                                             _q2.value(3).toLongLong()
                                            )
                                                         );
-#endif
             }
         }
-
+        query_string=s_m.arg(revision);
+        _q2.prepare(query_string);
+        if (!_q2.exec()) {
+            //qDebug("Could not select values: %s",_q2.lastError().text().TOUTF8().data());
+        } else {
+            if (_q2.next()) {
+                QByteArray byteArray = _q2.value(0).toByteArray();
+                QBuffer buffer(&byteArray);
+                QDataStream in(&buffer);
+                in >> target[revision].m_MergedInRevisions;
+            }
+        }
     }
     return true;
 }
@@ -490,17 +551,19 @@ bool svn::cache::ReposLog::itemExists(const svn::Revision&peg,const svn::Path&pa
 {
     /// @todo this moment I have no idea how to check real  with all moves and deletes of parent folders without a hell of sql statements so we make it quite simple: it exists if we found it.
 
+    Q_UNUSED(peg);
+    Q_UNUSED(path);
 
 #if 0
     static QString _s1("select revision from changeditems where changeditem='%1' and action='A' and revision<=%2 order by revision desc limit 1");
-    QSqlQuery _q(QString::null,m_Database);
+    QSqlQuery _q(QString(),m_Database);
     QString query_string=QString(_s1).arg(path.native()).arg(peg.revnum());
     if (!_q.exec(query_string)) {
-        qDebug("Could not select values: %s",_q.lastError().text().TOUTF8().data());
-        qDebug(_q.lastQuery().TOUTF8().data());
+        //qDebug("Could not select values: %s",_q.lastError().text().TOUTF8().data());
+        //qDebug(_q.lastQuery().TOUTF8().data());
         throw svn::cache::DatabaseException(QString("Could not select values: ")+_q.lastError().text(),_q.lastError().number());
     }
-    qDebug(_q.lastQuery().TOUTF8().data());
+    //qDebug(_q.lastQuery().TOUTF8().data());
 
 
     svn::Path _p = path;
@@ -517,19 +580,36 @@ bool svn::cache::ReposLog::itemExists(const svn::Revision&peg,const svn::Path&pa
 
 bool svn::cache::ReposLog::isValid()const
 {
-#if QT_VERSION < 0x040000
-    if (!m_Database) {
-#else
     if (!m_Database.isValid()) {
-#endif
         m_Database = LogCache::self()->reposDb(m_ReposRoot);
-#if QT_VERSION < 0x040000
-        if (!m_Database) {
-#else
         if (!m_Database.isValid()) {
-#endif
             return false;
         }
     }
     return true;
 }
+
+void svn::cache::ReposLog::cleanLogEntries()
+{
+
+    if (!isValid()) {
+        return;
+    }
+    m_Database.transaction();
+    QSqlQuery _q(QString(),m_Database);
+    if (!_q.exec("delete from logentries")) {
+        m_Database.rollback();
+        return;
+    }
+    if (!_q.exec("delete from changeditems")) {
+        m_Database.rollback();
+        return;
+    }
+    if (!_q.exec("delete from mergeditems")) {
+        m_Database.rollback();
+        return;
+    }
+
+    m_Database.commit();
+    _q.exec("vacuum");
+}
