@@ -1,6 +1,6 @@
 /*
  * Port for usage with qt-framework and development for kdesvn
- * (C) 2005-2007 by Rajko Albrecht
+ * Copyright (C) 2005-2009 by Rajko Albrecht (ral@alwins-world.de)
  * http://kdesvn.alwins-world.de
  */
 /*
@@ -31,69 +31,58 @@
 #pragma warning( disable: 4786 )// debug symbol truncated
 #endif
 // svncpp
-#include "svnqt/client_impl.hpp"
+#include "svnqt/client_impl.h"
 
 // subversion api
 #include "svn_client.h"
 
-#include "svnqt/exception.hpp"
-#include "svnqt/pool.hpp"
-#include "svnqt/targets.hpp"
-#include "svnqt/svnqt_defines.hpp"
-#include "svnqt/stringarray.hpp"
-
-#include "svnqt/helper.hpp"
+#include "svnqt/exception.h"
+#include "svnqt/pool.h"
+#include "svnqt/targets.h"
+#include "svnqt/svnqt_defines.h"
+#include "svnqt/stringarray.h"
+#include "svnqt/client_parameter.h"
+#include "svnqt/client_commit_parameter.h"
+#include "svnqt/client_update_parameter.h"
+#include "svnqt/url.h"
 
+#include "svnqt/helper.h"
+    
 namespace svn
 {
-  svn_revnum_t
-  Client_impl::checkout (const Path& url, const Path & destPath,
-              const Revision & revision,
-              const Revision & peg,
-              svn::Depth depth,
-              bool ignore_externals,
-              bool overwrite
-                        ) throw (ClientException)
+  Revision
+  Client_impl::checkout (const CheckoutParameter&parameters) throw (ClientException)
   {
     Pool subPool;
     svn_revnum_t revnum = 0;
-    Path up(url);
     svn_error_t * error = 0;
 #if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
     error = svn_client_checkout3(&revnum,
-                up.cstr(),
-                destPath.cstr(),
-                peg.revision(),
-                revision.revision (),
-                internal::DepthToSvn(depth),
-                ignore_externals,
-                overwrite,
+                parameters.moduleName().cstr(),
+                parameters.destination().cstr(),
+                parameters.peg().revision(),
+                parameters.revision().revision (),
+                internal::DepthToSvn(parameters.depth()),
+                parameters.ignoreExternals(),
+                parameters.overWrite(),
                 *m_context,
                 subPool);
 #else
-    bool recurse = depth==DepthInfinity;
+    bool recurse = parameters.depth()==DepthInfinity;
     Q_UNUSED(overwrite);
     error = svn_client_checkout2(&revnum,
-                           up.cstr(),
-                           destPath.cstr(),
-                           peg.revision(),
-                           revision.revision (),
-                           recurse,
-                           ignore_externals,
+                parameters.moduleName().cstr(),
+                parameters.destination().cstr(),
+                parameters.peg().revision(),
+                parameters.revision().revision (),
+                recurse,
+                parameters.ignoreExternals(),
                            *m_context,
                            subPool);
 #endif
     if(error != NULL)
       throw ClientException (error);
-    return revnum;
-  }
-
-  Revision Client_impl::remove (const Path & path,bool force,
-                            bool keep_local,
-                            const PropertiesMap&revProps) throw (ClientException)
-  {
-      Targets targets (path.path());
-      return remove(targets,force,keep_local,revProps);
+    return Revision(revnum);
   }
 
   Revision
@@ -196,13 +185,7 @@ namespace svn
   }
 
   Revisions
-  Client_impl::update (const Targets & path,
-                  const Revision & revision,
-                  Depth depth,
-                  bool ignore_externals,
-                  bool allow_unversioned,
-                  bool sticky_depth
-                      ) throw (ClientException)
+  Client_impl::update (const UpdateParameter&params) throw (ClientException)
   {
     Pool pool;
     Revisions resulting;
@@ -210,18 +193,17 @@ namespace svn
 
     apr_pool_t *apr_pool = pool.pool();
     apr_array_header_t *apr_revisions = apr_array_make (apr_pool,
-                      path.size(),
+                      params.targets().size(),
                       sizeof (svn_revnum_t));
-    if (depth==DepthUnknown) {
-        depth=DepthInfinity;
-    }
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
-    error = svn_client_update3(&apr_revisions,path.array(pool),revision,internal::DepthToSvn(depth),sticky_depth,ignore_externals,allow_unversioned,*m_context,pool);
+#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 7)) || (SVN_VER_MAJOR > 1)
+    error = svn_client_update4(&apr_revisions,params.targets().array(pool),params.revision(),
+                               internal::DepthToSvn(params.depth()),params.sticky_depth(),
+                               params.ignore_externals(),params.allow_unversioned(),
+                               params.add_as_modification(),params.make_parents(),
+                               *m_context,pool
+                              );
 #else
-    bool recurse = depth==DepthInfinity;
-    Q_UNUSED(sticky_depth);
-    Q_UNUSED(allow_unversioned);
-    error = svn_client_update2(&apr_revisions,path.array(pool),revision,recurse,ignore_externals,*m_context,pool);
+    error = svn_client_update3(&apr_revisions,params.targets().array(pool),params.revision(),internal::DepthToSvn(params.depth()),params.sticky_depth(),params.ignore_externals(),params.allow_unversioned(),*m_context,pool);
 #endif
     if (error!=NULL) {
         throw ClientException(error);
@@ -237,41 +219,34 @@ namespace svn
   }
 
   svn::Revision
-  Client_impl::commit (const Targets & targets, const QString& message,
-                       svn::Depth depth,bool keep_locks,
-                       const svn::StringArray&changelist,
-                       const PropertiesMap&revProps,
-                       bool keep_changelist) throw (ClientException)
+  Client_impl::commit (const CommitParameter&parameters) throw (ClientException)
   {
     Pool pool;
 
-    m_context->setLogMessage (message);
+    m_context->setLogMessage (parameters.message());
     svn_commit_info_t *commit_info = NULL;
 
 #if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
     svn_error_t * error =
             svn_client_commit4 (
                 &commit_info,
-                targets.array (pool),
-                internal::DepthToSvn(depth),
-                keep_locks,
-                keep_changelist,
-                changelist.array(pool),
-                map2hash(revProps,pool),
+                parameters.targets().array (pool),
+                internal::DepthToSvn(parameters.depth()),
+                parameters.keepLocks(),
+                parameters.keepChangeList(),
+                parameters.changeList().array(pool),
+                map2hash(parameters.revisionProperties(),pool),
                 *m_context,
                 pool);
 #else
-    Q_UNUSED(changelist);
-    Q_UNUSED(keep_changelist);
-    Q_UNUSED(revProps);
-    bool recurse = depth==DepthInfinity;
+    bool recurse = parameters.depth()==DepthInfinity;
 
     svn_error_t * error =
       svn_client_commit3
                         (&commit_info,
-                         targets.array (pool),
+                         parameters.targets().array (pool),
                          recurse,
-                         keep_locks,
+                         parameters.keepLocks(),
                          *m_context,
                          pool);
 #endif
@@ -286,35 +261,58 @@ namespace svn
   }
 
   Revision
-    Client_impl::copy(const Targets & srcPaths,
-                    const Revision & srcRevision,
-                    const Revision &pegRevision,
-                    const Path & destPath,
-                     bool asChild,bool makeParent,
-                     const PropertiesMap&revProps
-                     ) throw (ClientException)
+    Client_impl::copy(const CopyParameter&parameter)throw (ClientException)
     {
-        if (srcPaths.size()<1)
+        if (parameter.srcPath().size()<1)
         {
             throw ClientException("Wrong size of sources.");
         }
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
+#if ((SVN_VER_MAJOR==1) && (SVN_VER_MINOR < 5) )
+        Revision rev;
+        if (parameter.srcPath().size()>1 && !paramter.getAsChild())
+        {
+            throw ClientException("Multiple sources not allowed");
+        }
+
+        Path _dest;
+        QString base,dir;
+        for (size_t j=0;j<parameter.srcPath().size();++j)
+        {
+            _dest=parameter.destination();
+            if (paramter.asChild()) {
+                sparameter.srcPath()[j].split(dir,base);
+                _dest.addComponent(base);
+            }
+            rev  = copy(parameter.srcPath()[j],srcRevision,_dest);
+        }
+        return rev;
+#else
         Pool pool;
         svn_commit_info_t *commit_info = 0L;
-        apr_array_header_t * sources = apr_array_make(pool,srcPaths.size(),sizeof(svn_client_copy_source_t *));
-        for (size_t j=0;j<srcPaths.size();++j)
+        apr_array_header_t * sources = apr_array_make(pool,parameter.srcPath().size(),sizeof(svn_client_copy_source_t *));
+        // not using .array() 'cause some extra information is needed for copy
+        for (size_t j=0;j<parameter.srcPath().size();++j)
         {
             svn_client_copy_source_t* source = (svn_client_copy_source_t*)apr_palloc(pool, sizeof(svn_client_copy_source_t));
-            source->path = apr_pstrdup(pool,srcPaths[j].path().TOUTF8());
-            source->revision=srcRevision.revision();
-            source->peg_revision=pegRevision.revision();
+            source->path = apr_pstrdup(pool,parameter.srcPath()[j].path().TOUTF8());
+            source->revision=parameter.srcRevision().revision();
+            source->peg_revision=parameter.pegRevision().revision();
             APR_ARRAY_PUSH(sources, svn_client_copy_source_t *) = source;
         }
+#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 6)) || (SVN_VER_MAJOR > 1)
+        svn_error_t * error =
+                svn_client_copy5(&commit_info,
+                    sources,
+                    parameter.destination().cstr(),
+                    parameter.asChild(),parameter.makeParent(),parameter.ignoreExternal(),
+                    map2hash(parameter.properties(),pool),*m_context,pool);
+#else
         svn_error_t * error =
                 svn_client_copy4(&commit_info,
                     sources,
-                    destPath.cstr(),
-                    asChild,makeParent,map2hash(revProps,pool),*m_context,pool);
+                    parameter.destination().cstr(),
+                    parameter.asChild(),parameter.makeParent(),map2hash(parameter.properties(),pool),*m_context,pool);
+#endif
         if (error!=0){
             throw ClientException (error);
         }
@@ -322,29 +320,6 @@ namespace svn
             return commit_info->revision;
         }
         return Revision::UNDEFINED;
-#else
-        Q_UNUSED(asChild);
-        Q_UNUSED(makeParent);
-        Q_UNUSED(revProps);
-        Q_UNUSED(pegRevision);
-        Revision rev;
-        if (srcPaths.size()>1 && !asChild)
-        {
-            throw ClientException("Multiple sources not allowed");
-        }
-
-        Path _dest;
-        QString base,dir;
-        for (size_t j=0;j<srcPaths.size();++j)
-        {
-            _dest=destPath;
-            if (asChild) {
-                srcPaths[j].split(dir,base);
-                _dest.addComponent(base);
-            }
-            rev  = copy(srcPaths[j],srcRevision,_dest);
-        }
-        return rev;
 #endif
     }
 
@@ -354,7 +329,7 @@ namespace svn
                 const Path & destPath) throw (ClientException)
   {
 #if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
-      return copy(srcPath,srcRevision,srcRevision,destPath,true,false);
+    return copy(CopyParameter(srcPath,destPath).srcRevision(srcRevision).asChild(true).makeParent(false));
 #else
       Pool pool;
     svn_commit_info_t *commit_info = NULL;
@@ -377,58 +352,19 @@ namespace svn
 #endif
   }
 
-  svn::Revision Client_impl::move (const Path & srcPath,
-                const Path & destPath,
-                bool force) throw (ClientException)
-  {
-
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
-    return move(srcPath,destPath,force,false,false,PropertiesMap());
-#else
-    Pool pool;
-    svn_commit_info_t *commit_info = 0;
-
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 4))
-    svn_error_t * error = svn_client_move4
-#else
-    svn_error_t * error = svn_client_move3
-#endif
-                     (&commit_info,
-                       srcPath.cstr (),
-                       destPath.cstr (),
-                       force,
-                       *m_context,
-                       pool);
-
-    if(error != 0) {
-        throw ClientException (error);
-    }
-    if (commit_info) {
-        return commit_info->revision;
-    }
-    return Revision::UNDEFINED;
-#endif
-  }
-
-  svn::Revision Client_impl::move (
-             const Targets & srcPaths,
-             const Path & destPath,
-             bool force,
-             bool asChild,
-             bool makeParent,
-             const PropertiesMap&revProps) throw (ClientException)
+  svn::Revision Client_impl::move (const CopyParameter&parameter) throw (ClientException)
   {
 #if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
       Pool pool;
       svn_commit_info_t *commit_info = 0;
       svn_error_t * error = svn_client_move5(
                                              &commit_info,
-                                             srcPaths.array(pool),
-                                             destPath.cstr(),
-                                             force,
-                                             asChild,
-                                             makeParent,
-                                             map2hash(revProps,pool),
+                                             parameter.srcPath().array(pool),
+                                             parameter.destination().cstr(),
+                                             parameter.force(),
+                                             parameter.asChild(),
+                                             parameter.makeParent(),
+                                             map2hash(parameter.properties(),pool),
                                              *m_context,
                                              pool
                                             );
@@ -440,8 +376,6 @@ namespace svn
       }
       return Revision::UNDEFINED;
 #else
-      Q_UNUSED(makeParent);
-      Q_UNUSED(revProps);
       Revision rev;
       if (srcPaths.size()>1 && !asChild)
       {
@@ -462,17 +396,6 @@ namespace svn
 #endif
   }
 
-  svn::Revision
-  Client_impl::mkdir (const Path & path,
-                 const QString& message,
-                 bool makeParent,
-                 const PropertiesMap&revProps
-                     ) throw (ClientException)
-  {
-    Targets targets(path.path());
-    return mkdir(targets,message,makeParent,revProps);
-  }
-
   svn::Revision
   Client_impl::mkdir (const Targets & targets,
                  const QString&msg,
@@ -504,7 +427,7 @@ namespace svn
 #endif
 
     /* important! otherwise next op on repository uses that logmessage again! */
-    m_context->setLogMessage(QString::null);
+    m_context->setLogMessage(QString());
 
     if(error != NULL)
       throw ClientException (error);
@@ -548,60 +471,53 @@ namespace svn
     }
   }
 
-  svn_revnum_t
-  Client_impl::doExport (const Path & srcPath,
-              const Path & destPath,
-              const Revision & revision,
-              const Revision & peg,
-              bool overwrite,
-              const QString&native_eol,
-              bool ignore_externals,
-              svn::Depth depth) throw (ClientException)
+  Revision
+  Client_impl::doExport (const CheckoutParameter&params) throw (ClientException)
   {
     Pool pool;
     svn_revnum_t revnum = 0;
     const char*_neol;
-    if (native_eol==QString::null) {
+    if (params.nativeEol().isNull()) {
         _neol = (const char*)0;
     } else {
-        _neol = native_eol.TOUTF8();
+        _neol = params.nativeEol().TOUTF8();
     }
 #if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
     svn_error_t * error =
             svn_client_export4(&revnum,
-                                srcPath.cstr(),
-                                destPath.cstr(),
-                                peg.revision(),
-                                revision.revision(),
-                                overwrite,
-                                ignore_externals,
-                                internal::DepthToSvn(depth),
+                                params.moduleName().cstr(),
+                                params.destination().cstr(),
+                                params.peg().revision(),
+                                params.revision().revision(),
+                                params.overWrite(),
+                                params.ignoreExternals(),
+                                internal::DepthToSvn(params.depth()),
                                 _neol,
                                 *m_context,
                                 pool);
 #else
-    bool recurse = depth==svn::DepthInfinity;
+    bool recurse = params.depth()==svn::DepthInfinity;
     svn_error_t * error =
       svn_client_export3(&revnum,
-                        srcPath.cstr(),
-                        destPath.cstr(),
-                        peg.revision(),
-                        revision.revision(),
-                        overwrite,
-                        ignore_externals,
-                        recurse,
-                        _neol,
-                         *m_context,
-                         pool);
+                            params.moduleName().cstr(),
+                            params.destination().cstr(),
+                            params.peg().revision(),
+                            params.revision().revision(),
+                            params.overWrite(),
+                            params.ignoreExternals(),
+                            recurse,
+                            _neol,
+                            *m_context,
+                            pool);
 #endif
     if(error != NULL)
       throw ClientException (error);
-    return revnum;
+    return Revision(revnum);
   }
 
-  svn_revnum_t
+  Revision
   Client_impl::doSwitch (
-                         const Path & path, const QString& url,
+                         const Path & path, const Url& url,
                          const Revision & revision,
                          Depth depth,
                          const Revision & peg,
@@ -613,12 +529,11 @@ namespace svn
     Pool pool;
     svn_revnum_t revnum = 0;
     svn_error_t * error = 0;
-
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
+    
     error = svn_client_switch2(
                                &revnum,
                                path.cstr(),
-                               url.TOUTF8(),
+                               url,
                                peg.revision(),
                                revision.revision(),
                                internal::DepthToSvn(depth),
@@ -628,29 +543,15 @@ namespace svn
                                *m_context,
                                pool
                               );
-#else
-    bool recurse = depth==DepthInfinity;
-    Q_UNUSED(peg);
-    Q_UNUSED(sticky_depth);
-    Q_UNUSED(ignore_externals);
-    Q_UNUSED(allow_unversioned);
-    error = svn_client_switch (&revnum,
-                         path.cstr(),
-                         url.TOUTF8(),
-                         revision.revision (),
-                         recurse,
-                         *m_context,
-                         pool);
-#endif
     if(error != NULL) {
         throw ClientException (error);
     }
-    return revnum;
+    return Revision(revnum);
   }
 
   Revision
   Client_impl::import (const Path & path,
-                  const QString& url,
+                  const Url& url,
                   const QString& message,
                   svn::Depth depth,
                   bool no_ignore,bool no_unknown_nodetype,
@@ -662,28 +563,13 @@ namespace svn
     Pool pool;
 
     m_context->setLogMessage (message);
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
     svn_error_t * error =
-        svn_client_import3(&commit_info,path.cstr (),url.TOUTF8(),
+        svn_client_import3(&commit_info,path.cstr (),url,
             internal::DepthToSvn(depth),no_ignore,no_unknown_nodetype,
                                  map2hash(revProps,pool),
                                  *m_context,pool);
-#else
-    bool recurse = depth==DepthInfinity;
-    Q_UNUSED(revProps);
-    Q_UNUSED(no_unknown_nodetype);
-
-    svn_error_t * error =
-        svn_client_import2(&commit_info,
-                        path.cstr (),
-                        url.TOUTF8(),
-                        !recurse,
-                        no_ignore,
-                        *m_context,
-                        pool);
-#endif
     /* important! otherwise next op on repository uses that logmessage again! */
-    m_context->setLogMessage(QString::null);
+    m_context->setLogMessage(QString());
 
     if(error != 0) {
         throw ClientException (error);
@@ -696,15 +582,15 @@ namespace svn
 
   void
   Client_impl::relocate (const Path & path,
-                    const QString& from_url,
-                    const QString& to_url,
+                    const Url& from_url,
+                    const Url& to_url,
                     bool recurse) throw (ClientException)
   {
     Pool pool;
     svn_error_t * error =
       svn_client_relocate (path.cstr (),
-                         from_url.TOUTF8(),
-                         to_url.TOUTF8(),
+                         from_url,
+                         to_url,
                          recurse,
                          *m_context,
                          pool);
