@@ -25,6 +25,9 @@
 #include "svnqt_defines.h"
 
 #include <svn_wc.h>
+#ifdef HAS_SVN_VERSION_H
+#include <svn_version.h>
+#endif
 
 namespace svn {
 
