@@ -1,29 +1,37 @@
 /***************************************************************************
- *   Copyright (C) 2007 by Rajko Albrecht  ral@alwins-world.de             *
+ *   Copyright (C) 2007-2009 by Rajko Albrecht  ral@alwins-world.de        *
  *   http://kdesvn.alwins-world.de/                                        *
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ * This program is free software; you can redistribute it and/or           *
+ * modify it under the terms of the GNU Lesser General Public              *
+ * License as published by the Free Software Foundation; either            *
+ * version 2.1 of the License, or (at your option) any later version.      *
  *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ * Lesser General Public License for more details.                         *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
+ * You should have received a copy of the GNU Lesser General Public        *
+ * License along with this program (in the file LGPL.txt); if not,         *
+ * write to the Free Software Foundation, Inc., 51 Franklin St,            *
+ * Fifth Floor, Boston, MA  02110-1301  USA                                *
+ *                                                                         *
+ * This software consists of voluntary contributions made by many          *
+ * individuals.  For exact contribution history, see the revision          *
+ * history and logs, available at http://kdesvn.alwins-world.de.           *
  ***************************************************************************/
 
-#include "conflictresult.hpp"
+#include "conflictresult.h"
 
-#include "svnqt_defines.hpp"
+#include "svnqt_defines.h"
 
 #include <svn_wc.h>
 
+#ifdef HAS_SVN_VERSION_H
+#include <svn_version.h>
+#endif
+
 namespace svn
 {
     ConflictResult::ConflictResult()
