@@ -1,7 +1,7 @@
-/* 
+/*
  * Port for usage with qt-framework and development for kdesvn
- * (C) 2005-2007 by Rajko Albrecht
- * http://www.alwins-world.de/wiki/programs/kdesvn
+ * Copyright (C) 2005-2009 by Rajko Albrecht (ral@alwins-world.de)
+ * http://kdesvn.alwins-world.de
  */
 /*
  * ====================================================================
@@ -29,8 +29,8 @@
  */
 
 // svncpp
-#include "lock_entry.hpp"
-#include "pool.hpp"
+#include "lock_entry.h"
+#include "pool.h"
 
 // subversion api
 #include "svn_time.h"
@@ -69,15 +69,15 @@ namespace svn
   {
     return token;
   }
-  const apr_time_t LockEntry::Date()const
+  const DateTime&LockEntry::Date()const
   {
     return date;
   }
-  const apr_time_t LockEntry::Expiration()const
+  const DateTime&LockEntry::Expiration()const
   {
     return exp;
   }
-  const bool LockEntry::Locked()const
+  bool LockEntry::Locked()const
   {
     return locked;
   }
@@ -99,7 +99,7 @@ namespace svn
     exp = 0;
   }
 
-  void LockEntry::init(svn_lock_t* src)
+  void LockEntry::init(const svn_lock_t* src)
   {
     if (src) {
       date = src->creation_date;
