@@ -1,6 +1,6 @@
 /*
  * Port for usage with qt-framework and development for kdesvn
- * (C) 2005-2007 by Rajko Albrecht (ral@alwins-world.de)
+ * Copyright (C) 2005-2009 by Rajko Albrecht (ral@alwins-world.de)
  * http://kdesvn.alwins-world.de
  */
 /*
@@ -28,9 +28,9 @@
  * ====================================================================
  */
 // svncpp
-#include "log_entry.hpp"
-#include "pool.hpp"
-#include "stringarray.hpp"
+#include "log_entry.h"
+#include "pool.h"
+#include "stringarray.h"
 
 // subversion api
 #include "svn_time.h"
