@@ -1,6 +1,6 @@
 /*
  * Port for usage with qt-framework and development for kdesvn
- * (C) 2005-2007 by Rajko Albrecht (ral@alwins-world.de)
+ * Copyright (C) 2005-2009 by Rajko Albrecht (ral@alwins-world.de)
  * http://kdesvn.alwins-world.de
  */
 /*
@@ -36,10 +36,10 @@
 #include "apr_strings.h"
 
 // svncpp
-#include "svnqt/targets.hpp"
-#include "svnqt/path.hpp"
-#include "svnqt/pool.hpp"
-#include "svnqt/svnqt_defines.hpp"
+#include "svnqt/targets.h"
+#include "svnqt/path.h"
+#include "svnqt/pool.h"
+#include "svnqt/svnqt_defines.h"
 
 #include <qstringlist.h>
 
